@@ -89,10 +89,10 @@ class Act():
         """Get the uwsgi port using lsof.  Requires that lsof and fuser be suid root"""
         self.uwsgi_ip = None; self.uwsgi_port = None
         timeout = 10
-        nap = 2
+        nap = 1
         starttime = time.time()
         elapsed = 0
-        while not valid and elapsed < timeout:
+        while elapsed < timeout:
             try:
                 fullport = uwsgi_portsniffer.port_from_lsof(self.vassal_file)
                 self.uwsgi_ip, self.uwsgi_port = fullport.split(':')
